@@ -132,7 +132,7 @@ sub in_request_body {
     my $spool = $conn->{spool} ||= ! $self->{connected} && [];
     if ($spool) {
 	$self->xdebug("spooling request body");
-	$conn->{relay}->mask(0,r=>0) if $_[1] ne ''; # data given
+	( $conn->{relay} || return )->mask(0,r=>0) if $_[1] ne ''; # data given
 	push @$spool,['in_request_body',@_];
 	return 1;
     }
@@ -203,8 +203,27 @@ sub _inrqhdr_connect_upstream {
 	$host =~s{^\[(.*)\]$}{$1};
 	$proto = 'https';
 	$page = '';
-	# dont' forward anything, but don't change header :)
-	$hdr = \( '' );
+
+	$self->xdebug("new request $method $host:$port");
+
+	if ( $upstream ) {
+	    ($host,$port) = @$upstream;
+	} else {
+	    # dont' forward anything, but don't change header :)
+	    $hdr = \( '' );
+	}
+
+    } elsif ( $uri eq 'internal://imp' ) {
+	# the plugin provides the data itself by replacing a dummy response
+	# header + body with the intended data
+	$self->{conn}->in(1,
+	    "HTTP/1.1 200 Ok\r\n".
+	    "Content-type: internal/internal\r\n".
+	    "Content-length: 2\r\n".
+	    "\r\n".
+	    "12",1);
+	return;
+
     } else {
 	($proto,$host,$port,$page) = ($1,$2,$3||80,$4)
 	    if $uri =~m{^(?:(\w+)://([^/\s]+?)(?::(\d+))?)?(/.*|$)};
@@ -215,6 +234,8 @@ sub _inrqhdr_connect_upstream {
 	return $self->fatal("bad proto: $proto"),undef
 	    if $proto ne 'http';
 
+	$self->xdebug("new request $method $proto://$host:$port$page");
+
 	if ( $upstream ) {
 	    # rewrite /page to method://host/page 
 	    my $p = $port == 80 ? '':":$port";
@@ -235,10 +256,10 @@ sub _inrqhdr_connect_upstream {
 	$keep_alive //= $$hdr =~m{\A.*HTTP/1\.1\r?\n}; 
     }
 
-    $self->xdebug("new request $method $proto://$host:$port$page");
     $time ||= AnyEvent->now;
     my $connect_cb = sub {
 	$self->{connected} = 1;
+	#debug("connected to $host.$port");
 	$self->{acct}{ctime} = AnyEvent->now - $time;
 	if ($$hdr ne '') {
 	    _forward($self,0,1,$$hdr);
